@@ -43,7 +43,7 @@ def bootstrap(
     scm_object_key,
     scm_skip_creation_of_repo,
     should_validate,
-    custom_source_git_url,
+    custom_source_action_git_url,
     custom_source_action_git_web_hook_ip_address,
     custom_source_action_custom_action_type_version,
     custom_source_action_custom_action_type_provider,
@@ -150,7 +150,7 @@ def bootstrap(
             {
                 "Configuration": {
                     "Owner": "Custom",
-                    "GitUrl": custom_source_git_url,
+                    "GitUrl": custom_source_action_git_url,
                     "Branch": branch,
                     "GitWebHookIpAddress": custom_source_action_git_web_hook_ip_address,
                     "CustomActionTypeVersion": custom_source_action_custom_action_type_version,
